@@ -23,7 +23,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include "application.h"
-#include "treeview.h"
+#include "legacy/treeview.h"
 
 enum
 {
@@ -49,6 +49,10 @@ enum
     COL_SESSION,
     COL_SEAT,
     COL_OWNER,
+    COL_DISK_WRITE_TOTAL,
+    COL_DISK_READ_TOTAL,
+    COL_DISK_WRITE_CURRENT,
+    COL_DISK_READ_CURRENT,
     COL_PRIORITY,
     COL_PIXBUF,
     COL_POINTER,
