@@ -2,13 +2,12 @@
 #ifndef _GSM_UTIL_H_
 #define _GSM_UTIL_H_
 
-#include <glib.h>
-#include <gtk/gtk.h>
+#include <gtkmm.h>
 #include <string>
 
 using std::string;
 
-GtkWidget*
+GtkLabel*
 procman_make_label_for_mmaps_or_ofiles(const char *format,
                                        const char *process_name,
                                        unsigned pid);
@@ -25,7 +24,7 @@ procman_debug_real(const char *file, int line, const char *func,
 
 #define procman_debug(FMT, ...) procman_debug_real(__FILE__, __LINE__, __func__, FMT, ##__VA_ARGS__)
 
-gchar * get_monospace_system_font_name (void);
+Glib::ustring get_monospace_system_font_name (void);
 
 inline string make_string(char *c_str)
 {
@@ -48,6 +47,10 @@ namespace procman
                              GtkTreeModel *model, GtkTreeIter *iter,
                              gpointer user_data);
 
+    void io_rate_cell_data_func(GtkTreeViewColumn *col, GtkCellRenderer *renderer,
+                             GtkTreeModel *model, GtkTreeIter *iter,
+                             gpointer user_data);
+
     void size_na_cell_data_func(GtkTreeViewColumn *col, GtkCellRenderer *renderer,
                                 GtkTreeModel *model, GtkTreeIter *iter,
                                 gpointer user_data);
@@ -137,6 +140,24 @@ namespace procman
         NonCopyable& operator=(const NonCopyable&) /* = delete */;
     };
 
+
+    // join the elements of c with sep
+    template<typename C, typename S>
+        auto join(const C& c, const S& sep) -> decltype(c[0] + sep)
+    {
+        decltype(c[0] + sep) r;
+        bool first = true;
+
+        for(const auto& e : c) {
+            if (!first) {
+                r += sep;
+            }
+            first = false;
+            r += e;
+        }
+
+        return r;
+    }
 }
 
 #endif /* _GSM_UTIL_H_ */
